package Data::Throttler::Backend::FastMmap;
# ABSTRACT: Data::Throttler backend for Cache::FastMmap
$Data::Throttler::Backend::FastMmap::VERSION = '0.01';
use strict;
use base 'Data::Throttler::Backend::Base';

use Fcntl qw(:flock);

sub exists {
    my ($self) = @_;
    $self->load ? 1 : 0;
}

sub lock {
    my ($self) = @_;
    open(my $lock_fh, '>>', $self->{lock_file}) or die $!;
    flock($lock_fh, LOCK_EX);
    $self->{lock_fh} = $lock_fh;
}

sub unlock {
    my ($self) = @_;
    close(delete $self->{lock_fh});
}

sub save {
    my ($self, $data) = @_;
    $self->{cache}->set( db => $data );
}

sub load {
    my ($self) = @_;
    $self->{cache}->get('db');
}

1;

=pod

=encoding UTF-8

=head1 NAME

Data::Throttler::Backend::FastMmap - Data::Throttler backend for Cache::FastMmap

=cut

__END__

# use Cache::FastMmap;
#
# sub init {
#     my ($self) = @_;
#     $self->{cache} = Cache::FastMmap->new();
# }
 
#  
#  # Uses Storable to serialize $Value to bytes for storage
#  $Cache->set($Key, $Value);
#  $Value = $Cache->get($Key);
#   
#   $Cache = Cache::FastMmap->new(serializer => '');
#    
